from banyarag.banyainstance import BanyaInstance
import os
# from banyarag import banyainstance

# 현재 작업 디렉토리 가져오기
pwd = os.getcwd()
folder_path = os.path.join(pwd, "devlibtest")



# 사용자 정보 설정
# API_KEY = "your_api_key_here"
# USER_EMAIL = "your_email@example.com"

API_KEY = "aHV4RRFdsDvoZKJL"
USER_EMAIL = "tony@nxdf.io"

# 업로드할 로컬 드라이브 경로 설정
DRIVE_PATH = folder_path

# 모델 설정
EMBEDDER_MODEL = ""
LLM_MODEL = ""

def main():
    # 1. BanyaInstance 초기화 (API Key와 User Email 포함)
    instance = BanyaInstance(server_url="https://train.banya.ai", api_key=API_KEY, user_email=USER_EMAIL)

    # 2. 드라이브 경로 설정
    if not instance.setDrivePath(DRIVE_PATH):
        print("드라이브 경로 설정 실패. 프로그램을 종료합니다.")
        return

    # 3. 파일 업로드 실행
    upload_timestamp = instance.uploadAllFiles()
    if not upload_timestamp:
        print("파일 업로드 실패. 프로그램을 종료합니다.")
        return

    # # 4. 업로드된 데이터로 학습 요청
    # chat_url = instance.trainRAG(upload_timestamp, EMBEDDER_MODEL, LLM_MODEL)
    # if not chat_url:
    #     print("학습 요청 실패. 프로그램을 종료합니다.")
    # else:
    #     print("학습 완료! 채팅 URL:", chat_url)

if __name__ == "__main__":
    main()
